```{include} ../README.md
```

```{eval-rst}
.. toctree::
    :maxdepth: 1
    :caption: Introduction

    introduction/ioc-container
    introduction/fastapi
    introduction/litestar
    introduction/inject-factories
    introduction/multiple-containers
    introduction/dynamic-container
    introduction/application-settings

.. toctree::
    :maxdepth: 1
    :caption: Providers

    providers/resources
    providers/context-resources
    providers/singleton
    providers/factories
    providers/async-factory
    providers/collections
    providers/selector
    providers/object
   
.. toctree::
    :maxdepth: 1
    :caption: Testing
    
    testing/provider-overriding

.. toctree::
    :maxdepth: 1
    :caption: For developers

    dev/main-decisions
    dev/contributing
```
